==> quidproquo-actionprocessor-awslambda-0.0.224.tgz: package/lib/esm/logic/dynamo/qpqDynamoOrm/buildDynamoUpdate.js <==
import { KvsUpdateActionType } from 'quidproquo-core';
import { getItemName, getValueName, buildAttributeValue } from './buildDynamoQuery';
export const buildUpdateExpressionAttributeNames = (updates) => {
    let attributeNames = {};
    for (let update of updates) {
        if (Array.isArray(update.attributePath)) {
            // Handle nested attributes
            for (let i = 0; i < update.attributePath.length; i++) {
                let attribute = update.attributePath[i];
                if (typeof attribute === 'string') {
                    const itemName = getItemName(attribute);
                    attributeNames[itemName] = attribute;
                    // Replace attribute name in path with safe name
                    update.attributePath[i] = itemName;
                }
            }
        }
        else {
            // Handle top-level attributes
            const itemName = getItemName(update.attributePath);
            attributeNames[itemName] = update.attributePath;
            update.attributePath = itemName;
        }
    }
    return attributeNames;
};
export const buildUpdateExpressionAttributeValues = (updates) => {
    let attributeValues = {};
    for (let update of updates) {
        if (update.value !== undefined && update.value !== null) {
            const valuePlaceholder = getValueName(update.value);
            attributeValues[valuePlaceholder] = buildAttributeValue(update.value);
        }
    }
    return Object.keys(attributeValues).length > 0 ? attributeValues : undefined;
};
const buildDynamoUpdateExpressionSet = (update) => {
    if (update.value === undefined || update.value === null) {
        throw new Error("Value must be provided for 'SET' action");
    }
    return `${getNestedItemName(update.attributePath)} = ${getValueName(update.value)}`;
};
const buildDynamoUpdateExpressionRemove = (update) => {
    return `${getNestedItemName(update.attributePath)}`;
};
const buildDynamoUpdateExpressionAdd = (update) => {
    if (update.value === undefined || update.value === null) {
        throw new Error("Value must be provided for 'ADD' action");
    }
    return `${getNestedItemName(update.attributePath)} ${getValueName(update.value)}`;
};
const buildDynamoUpdateExpressionDelete = (update) => {
    if (update.value !== undefined && update.value !== null) {
        return `${getNestedItemName(update.attributePath)} ${getValueName(update.value)}`;
    }
    else {
        return `${getNestedItemName(update.attributePath)}`;
    }
};
const getNestedItemName = (attributePath) => {
    if (Array.isArray(attributePath)) {
        let path = '';
        for (let i = 0; i < attributePath.length; i++) {
            if (typeof attributePath[i] === 'string') {
                path += `.${getItemName(attributePath[i])}`;
            }
            else {
                path += `[${attributePath[i]}]`;
            }
        }
        return path.substring(1); // remove the leading dot
    }
    else {
        return getItemName(attributePath);
    }
};
const buildDynamoUpdateExpressionPart = (update, updateIndex) => {
    switch (update.action) {
        case KvsUpdateActionType.Set:
            return buildDynamoUpdateExpressionSet(update);
        case KvsUpdateActionType.Remove:
            return buildDynamoUpdateExpressionRemove(update);
        case KvsUpdateActionType.Add:
            return buildDynamoUpdateExpressionAdd(update);
        case KvsUpdateActionType.Delete:
            return buildDynamoUpdateExpressionDelete(update);
        default:
            throw new Error(`Invalid update action type: ${update.action}`);
    }
};
export const buildDynamoUpdateExpressionForType = (type, kvsUpdate) => {
    const actions = kvsUpdate.filter((update) => update.action === type);
    // If there are no actions of this type, return an empty string
    if (actions.length === 0) {
        return '';
    }
    const expressions = actions
        .map((update, index) => buildDynamoUpdateExpressionPart(update, index))
        .join(', ');
    switch (type) {
        case KvsUpdateActionType.Set:
            return `SET ${expressions}`;
        case KvsUpdateActionType.Remove:
            return `REMOVE ${expressions}`;
        case KvsUpdateActionType.Add:
            return `ADD ${expressions}`;
        case KvsUpdateActionType.Delete:
            return `DELETE ${expressions}`;
        default:
            throw new Error(`Invalid update action type: ${type}`);
    }
};
export const buildDynamoUpdateExpression = (updates) => {
    const updatesExpressions = [
        KvsUpdateActionType.Set,
        KvsUpdateActionType.Remove,
        KvsUpdateActionType.Add,
        KvsUpdateActionType.Delete,
    ]
        .map((kvsUpdateActionType) => buildDynamoUpdateExpressionForType(kvsUpdateActionType, updates))
        .filter((expression) => !!expression);
    const result = updatesExpressions.join(' ');
    console.log('Update Expression: ', result);
    return result;
};

==> quidproquo-actionprocessor-awslambda-0.0.242.tgz: package/lib/esm/logic/dynamo/qpqDynamoOrm/buildDynamoUpdate.js <==
import { KvsUpdateActionType } from 'quidproquo-core';
import { buildAttributeValue, getItemName, getValueName } from './buildDynamoQuery';
export const buildUpdateExpressionAttributeNames = (updates) => {
    let attributeNames = {};
    for (let update of updates) {
        if (Array.isArray(update.attributePath)) {
            // Handle nested attributes
            for (let i = 0; i < update.attributePath.length; i++) {
                let attribute = update.attributePath[i];
                if (typeof attribute === 'string') {
                    const itemName = getItemName(attribute);
                    attributeNames[itemName] = attribute;
                    // Replace attribute name in path with safe name
                    update.attributePath[i] = itemName;
                }
            }
        }
        else {
            // Handle top-level attributes
            const itemName = getItemName(update.attributePath);
            attributeNames[itemName] = update.attributePath;
            update.attributePath = itemName;
        }
    }
    return attributeNames;
};
export const buildUpdateExpressionAttributeValues = (updates) => {
    let attributeValues = {};
    for (let update of updates) {
        if (update.value !== undefined && update.value !== null) {
            const valuePlaceholder = getValueName(update.value);
            attributeValues[valuePlaceholder] = buildAttributeValue(update.value);
        }
    }
    return Object.keys(attributeValues).length > 0 ? attributeValues : undefined;
};
const buildDynamoUpdateExpressionSet = (update) => {
    if (update.value === undefined || update.value === null) {
        throw new Error("Value must be provided for 'SET' action");
    }
    return `${getNestedItemName(update.attributePath)} = ${getValueName(update.value)}`;
};
const buildDynamoUpdateExpressionRemove = (update) => {
    return `${getNestedItemName(update.attributePath)}`;
};
const buildDynamoUpdateExpressionAdd = (update) => {
    if (update.value === undefined || update.value === null) {
        throw new Error("Value must be provided for 'ADD' action");
    }
    return `${getNestedItemName(update.attributePath)} ${getValueName(update.value)}`;
};
const buildDynamoUpdateExpressionDelete = (update) => {
    if (update.value !== undefined && update.value !== null) {
        return `${getNestedItemName(update.attributePath)} ${getValueName(update.value)}`;
    }
    else {
        return `${getNestedItemName(update.attributePath)}`;
    }
};
const getNestedItemName = (attributePath) => {
    if (Array.isArray(attributePath)) {
        let path = '';
        for (let i = 0; i < attributePath.length; i++) {
            if (typeof attributePath[i] === 'string') {
                path += `.${getItemName(attributePath[i])}`;
            }
            else {
                path += `[${attributePath[i]}]`;
            }
        }
        return path.substring(1); // remove the leading dot
    }
    else {
        return getItemName(attributePath);
    }
};
const buildDynamoUpdateExpressionPart = (update, updateIndex) => {
    switch (update.action) {
        case KvsUpdateActionType.Set:
            return buildDynamoUpdateExpressionSet(update);
        case KvsUpdateActionType.Remove:
            return buildDynamoUpdateExpressionRemove(update);
        case KvsUpdateActionType.Add:
            return buildDynamoUpdateExpressionAdd(update);
        case KvsUpdateActionType.Delete:
            return buildDynamoUpdateExpressionDelete(update);
        default:
            throw new Error(`Invalid update action type: ${update.action}`);
    }
};
export const buildDynamoUpdateExpressionForType = (type, kvsUpdate) => {
    const actions = kvsUpdate.filter((update) => update.action === type);
    // If there are no actions of this type, return an empty string
    if (actions.length === 0) {
        return '';
    }
    const expressions = actions.map((update, index) => buildDynamoUpdateExpressionPart(update, index)).join(', ');
    switch (type) {
        case KvsUpdateActionType.Set:
            return `SET ${expressions}`;
        case KvsUpdateActionType.Remove:
            return `REMOVE ${expressions}`;
        case KvsUpdateActionType.Add:
            return `ADD ${expressions}`;
        case KvsUpdateActionType.Delete:
            return `DELETE ${expressions}`;
        default:
            throw new Error(`Invalid update action type: ${type}`);
    }
};
export const buildDynamoUpdateExpression = (updates) => {
    const updatesExpressions = [KvsUpdateActionType.Set, KvsUpdateActionType.Remove, KvsUpdateActionType.Add, KvsUpdateActionType.Delete]
        .map((kvsUpdateActionType) => buildDynamoUpdateExpressionForType(kvsUpdateActionType, updates))
        .filter((expression) => !!expression);
    const result = updatesExpressions.join(' ');
    console.log('Update Expression: ', result);
    return result;
};
